package ru.myitschool.work.ui.profile;

import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import androidx.lifecycle.ViewModel;

import ru.myitschool.work.data.UserRepositoryImpl;
import ru.myitschool.work.domain.GetAllUserHistoryUseCase;
import ru.myitschool.work.domain.GetUserByUsernameUseCase;
import ru.myitschool.work.domain.entities.HistoryEntity;
import ru.myitschool.work.domain.entities.UserEntity;
import ru.myitschool.work.domain.sign.IsUserExistUseCase;

public class ProfileViewModel extends ViewModel {
    private final MutableLiveData<State> mutableStateLiveData = new MutableLiveData<>();

    public final LiveData<State> stateLiveData = mutableStateLiveData;

    public final GetUserByUsernameUseCase getUserByUsernameUseCase = new GetUserByUsernameUseCase(
            UserRepositoryImpl.getInstance()
    );

    /*public final GetAllUserHistoryUseCase getAllUserHistoryListUseCase = new GetAllUserHistoryUseCase(
            UserRepositoryImpl.getInstance()
    );*/
    private final IsUserExistUseCase isUserExistUseCase = new IsUserExistUseCase(
            UserRepositoryImpl.getInstance()
    );

    public void load(@NonNull String username) {
        mutableStateLiveData.setValue(new State(null, null, true));
        postUserByUsername(username);
    }

    private void postUserByUsername(String username) {
        final String currentUsername = username;
        if (currentUsername == null || currentUsername.isEmpty()) {
            //mutableErrorLiveData.postValue("Login cannot be null");
            return;
        }
        getUserByUsernameUseCase.execute(currentUsername, status -> {
            if (status.getValue() == null || status.getErrors() != null) {
                Log.d("tagg", status.getErrors().toString());
                //mutableErrorLiveData.postValue("Something wrong. Try later =(" + status.getErrors());
                return;
            }
            //userCheckCompleted = true;
            if (status.getStatusCode() == 200 && status.getErrors() == null) {
                mutableStateLiveData.postValue(new ProfileViewModel.State(
                        status.getErrors() != null ? status.getErrors().getLocalizedMessage() : null,
                        status.getValue(),
                        false
                ));
            } else {
                mutableStateLiveData.postValue(new State(
                        status.getErrors() != null ? status.getErrors().getLocalizedMessage() : null,
                        null,
                        false
                ));
            }
            //isNewAccount = !status.getValue();
            //checkAuth();
            /*if(isNewAccount) {
                mutableStateLiveData.postValue(
                        new State(R.string.title_user_new, R.string.button_user_new, true)
                );
            } else {
                mutableStateLiveData.postValue(
                        new State(R.string.title_user_exist, R.string.button_user_exist, true)
                );
            }*/
        });
    }




    public class State {
        @Nullable
        private final String errorMessage;

        @Nullable
        private final UserEntity user;

        private final boolean isLoading;

        public State(@Nullable String errorMessage, @Nullable UserEntity user, boolean isLoading) {
            this.errorMessage = errorMessage;
            this.user = user;
            this.isLoading = isLoading;
        }

        @Nullable
        public String getErrorMessage() {
            return errorMessage;
        }

        @Nullable
        public UserEntity getUser() {
            return user;
        }

        public boolean isLoading() {
            return isLoading;
        }
    }
}
